@@ -7,10 +7,10 @@ package Comics::Plugin::GeekAndPoke;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 
 our $name    = "Geek&Poke";
-our $url     = "https://geek-and-poke.com/";
+our $url     = "http://geek-and-poke.com/";
 our $pattern =
   qr{ <noscript>
       <img \s+
